package com.javaproxy;

import android.app.Application;
import android.content.BroadcastReceiver;
import android.content.pm.ActivityInfo;
import android.content.pm.PackageInfo;
import android.content.pm.ResolveInfo;
import android.content.pm.ServiceInfo;
import android.content.res.AssetManager;
import android.content.res.Resources;
import java.io.Serializable;
import java.util.ArrayList;
import java.util.Collection;
import java.util.HashMap;
import java.util.List;
import java.util.Map;

/* loaded from: com_javaproxy.jar:com/javaproxy/PlugInfo.class */
public class PlugInfo implements Serializable {
    private String id;
    private String filePath;
    private PackageInfo packageInfo;
    private Map<String, ResolveInfo> activities;
    private ResolveInfo mainActivity;
    private List<ResolveInfo> services;
    private List<ResolveInfo> receivers;
    private List<ResolveInfo> providers;
    private transient ClassLoader classLoader;
    private transient Application application;
    private transient AssetManager assetManager;
    private transient Resources resources;
    private transient boolean isApplicationOnCreated;

    public String getPackageName() {
        return this.packageInfo.packageName;
    }

    public ActivityInfo findActivityByClassNameFromPkg(String actName) {
        if (actName.startsWith(".")) {
            actName = String.valueOf(getPackageName()) + actName;
        }
        if (this.packageInfo.activities == null) {
            return null;
        }
        for (ActivityInfo act : this.packageInfo.activities) {
            if (act.name.equals(actName)) {
                return act;
            }
        }
        return null;
    }

    public ActivityInfo findActivityByClassName(String actName) {
        if (this.packageInfo.activities == null) {
            return null;
        }
        if (actName.startsWith(".")) {
            actName = String.valueOf(getPackageName()) + actName;
        }
        ResolveInfo act = this.activities.get(actName);
        if (act == null) {
            return null;
        }
        return act.activityInfo;
    }

    public ActivityInfo findActivityByAction(String action) {
        if (this.activities == null || this.activities.isEmpty()) {
            return null;
        }
        for (ResolveInfo act : this.activities.values()) {
            if (act.filter != null && act.filter.hasAction(action)) {
                return act.activityInfo;
            }
        }
        return null;
    }

    public ActivityInfo findReceiverByClassName(String className) {
        if (this.packageInfo.receivers == null) {
            return null;
        }
        for (ActivityInfo receiver : this.packageInfo.receivers) {
            if (receiver.name.equals(className)) {
                return receiver;
            }
        }
        return null;
    }

    public ServiceInfo findServiceByClassName(String className) {
        if (this.packageInfo.services == null) {
            return null;
        }
        for (ServiceInfo service : this.packageInfo.services) {
            if (service.name.equals(className)) {
                return service;
            }
        }
        return null;
    }

    public ServiceInfo findServiceByAction(String action) {
        if (this.services == null || this.services.isEmpty()) {
            return null;
        }
        for (ResolveInfo ser : this.services) {
            if (ser.filter != null && ser.filter.hasAction(action)) {
                return ser.serviceInfo;
            }
        }
        return null;
    }

    public void addActivity(ResolveInfo activity) {
        if (this.activities == null) {
            this.activities = new HashMap(15);
        }
        fixActivityInfo(activity.activityInfo);
        this.activities.put(activity.activityInfo.name, activity);
        if (this.mainActivity == null && activity.filter != null && activity.filter.hasAction("android.intent.action.MAIN") && activity.filter.hasCategory("android.intent.category.LAUNCHER")) {
            this.mainActivity = activity;
        }
    }

    private void fixActivityInfo(ActivityInfo activityInfo) {
        if (activityInfo != null && activityInfo.name.startsWith(".")) {
            activityInfo.name = String.valueOf(getPackageName()) + activityInfo.name;
        }
    }

    public void addReceiver(ResolveInfo receiver) {
        if (this.receivers == null) {
            this.receivers = new ArrayList();
        }
        this.receivers.add(receiver);
    }

    public void addService(ResolveInfo service) {
        if (this.services == null) {
            this.services = new ArrayList();
        }
        this.services.add(service);
    }

    public String getId() {
        return this.id;
    }

    public void setId(String id) {
        this.id = id;
    }

    public String getFilePath() {
        return this.filePath;
    }

    public void setFilePath(String filePath) {
        this.filePath = filePath;
    }

    public PackageInfo getPackageInfo() {
        return this.packageInfo;
    }

    public void setPackageInfo(PackageInfo packageInfo) {
        this.packageInfo = packageInfo;
        this.activities = new HashMap(packageInfo.activities.length);
    }

    public Application getApplication() {
        return this.application;
    }

    public void setApplication(Application application) {
        this.application = application;
    }

    public AssetManager getAssets() {
        return this.assetManager;
    }

    public void setAssetManager(AssetManager assetManager) {
        this.assetManager = assetManager;
    }

    public Resources getResources() {
        return this.resources;
    }

    public void setResources(Resources resources) {
        this.resources = resources;
    }

    public Collection<ResolveInfo> getActivities() {
        if (this.activities == null) {
            return null;
        }
        return this.activities.values();
    }

    public List<ResolveInfo> getServices() {
        return this.services;
    }

    public void setServices(List<ResolveInfo> services) {
        this.services = services;
    }

    public List<ResolveInfo> getProviders() {
        return this.providers;
    }

    public void setProviders(List<ResolveInfo> providers) {
        this.providers = providers;
    }

    public ResolveInfo getMainActivity() {
        return this.mainActivity;
    }

    public List<ResolveInfo> getReceivers() {
        return this.receivers;
    }

    public ClassLoader getClassLoader() {
        return this.classLoader;
    }

    public void setClassLoader(ClassLoader classLoader) {
        this.classLoader = classLoader;
    }

    public int hashCode() {
        int result = (31 * 1) + (this.id == null ? 0 : this.id.hashCode());
        return result;
    }

    public boolean equals(Object obj) {
        if (this == obj) {
            return true;
        }
        if (obj == null || getClass() != obj.getClass()) {
            return false;
        }
        PlugInfo other = (PlugInfo) obj;
        if (this.id == null) {
            if (other.id != null) {
                return false;
            }
            return true;
        }
        if (!this.id.equals(other.id)) {
            return false;
        }
        return true;
    }

    public boolean isApplicationCreated() {
        return this.application != null || this.isApplicationOnCreated;
    }

    /* JADX WARN: Multi-variable type inference failed */
    /* JADX WARN: Type inference failed for: r0v2 */
    /* JADX WARN: Type inference failed for: r0v3, types: [java.lang.Throwable] */
    /* JADX WARN: Type inference failed for: r0v5 */
    public void ensureApplicationCreated() {
        if (isApplicationCreated()) {
            ?? r0 = this;
            synchronized (r0) {
                try {
                    this.application.onCreate();
                    if (this.receivers != null && this.receivers.size() > 0) {
                        for (ResolveInfo resolveInfo : this.receivers) {
                            if (resolveInfo.activityInfo != null) {
                                try {
                                    BroadcastReceiver broadcastReceiver = (BroadcastReceiver) this.classLoader.loadClass(resolveInfo.activityInfo.name).newInstance();
                                    this.application.registerReceiver(broadcastReceiver, resolveInfo.filter);
                                } catch (Throwable e) {
                                    e.printStackTrace();
                                }
                            }
                        }
                    }
                } catch (Throwable th) {
                }
                this.isApplicationOnCreated = true;
                r0 = r0;
            }
        }
    }

    public String toString() {
        return String.valueOf(super.toString()) + "[ id=" + this.id + ", pkg=" + getPackageName() + " ]";
    }
}
